@@ -253,9 +253,21 @@ class Neo4jCsvPublisher(Publisher):
 
         with open(node_file, 'r', encoding='utf8') as node_csv:
             for node_record in pandas.read_csv(node_csv, na_filter=False).to_dict(orient="records"):
+                LOGGER.info('loop time %s', str(time.time() - self.now))
+
+                self.now = time.time()
                 stmt = self.create_node_merge_statement(node_record=node_record)
+                LOGGER.info('create node statement time %s', str(time.time() - self.now))
+
+                self.now = time.time()
                 params = self._create_props_param(node_record)
+                LOGGER.info('create prop time %s', str(time.time() - self.now))
+                
+                self.now = time.time()
                 tx = self._execute_statement(stmt, tx, params)
+                LOGGER.info('neo query time %s', str(time.time() - self.now))
+                self.now = time.time()
+
         return tx
 
     def is_create_only_node(self, node_record: dict) -> bool:
@@ -317,10 +329,12 @@ class Neo4jCsvPublisher(Publisher):
                         relation=rel_record[RELATION_TYPE],
                         reverse_relation=rel_record[RELATION_REVERSE_TYPE])
 
+
                     if stmt:
                         tx = self._execute_statement(stmt, tx=tx, params=params)
                         count += 1
 
+
             LOGGER.info('Executed pre-processing Cypher statement %i times', count)
 
         with open(relation_file, 'r', encoding='utf8') as relation_csv:
@@ -330,10 +344,12 @@ class Neo4jCsvPublisher(Publisher):
                 while exception_exists and retries_for_exception > 0:
                     try:
                         stmt = self.create_relationship_merge_statement(rel_record=rel_record)
+                        
                         params = self._create_props_param(rel_record)
                         tx = self._execute_statement(stmt, tx, params,
                                                      expect_result=self._confirm_rel_created)
                         exception_exists = False
+
                     except TransientError as e:
                         if rel_record[RELATION_START_LABEL] in self.deadlock_node_labels \
                                 or rel_record[RELATION_END_LABEL] in self.deadlock_node_labels:
@@ -409,10 +425,12 @@ class Neo4jCsvPublisher(Publisher):
         props.append(f"{identifier}.{LAST_UPDATED_EPOCH_MS} = timestamp()")
 
         return ', '.join(props)
+        
 
     def _execute_statement(self,
                            stmt: str,
                            tx: Transaction,
+
                            params: dict = None,
                            expect_result: bool = False) -> Transaction:
         """
@@ -426,9 +444,6 @@ class Neo4jCsvPublisher(Publisher):
         """
         try:
             LOGGER.debug('Executing statement: %s with params %s', stmt, params)
-            LOGGER.info('start time %s', str(time.time() - self.now))
-            self.now = time.time()
-
             result = tx.run(str(stmt).encode('utf-8', 'ignore'), parameters=params)
             if expect_result and not result.single():
                 raise RuntimeError(f'Failed to executed statement: {stmt}')
@@ -442,8 +457,6 @@ class Neo4jCsvPublisher(Publisher):
             if self._count > 1 and self._count % self._progress_report_frequency == 0:
                 LOGGER.info(f'Processed {self._count} statements so far')
 
-            LOGGER.info('end time %s', str(time.time() - self.now))
-            self.now = time.time()
             return tx
         except Exception as e:
             LOGGER.exception('Failed to execute Cypher query')
